@@ -1,6 +1,5 @@
 package DTL::Fast::Filter;
 use strict; use utf8; use warnings FATAL => 'all'; 
-use Carp qw(confess);
 
 use DTL::Fast::Template;
 
@@ -22,7 +21,7 @@ sub parse_parameters{return shift;}
 
 sub filter
 {
-    confess "This is abstract method and it must be overrided";
+    die "This is abstract method and it must be overrided";
 }
 
 1;
