@@ -1,7 +1,6 @@
 package DTL::Fast::Filter::Stringformat;
 use strict; use utf8; use warnings FATAL => 'all'; 
 use parent 'DTL::Fast::Filter';
-use Carp;
 
 $DTL::Fast::FILTER_HANDLERS{'stringformat'} = __PACKAGE__;
 
@@ -11,7 +10,7 @@ use DTL::Fast::Variable;
 sub parse_parameters
 {
     my $self = shift;
-    croak "No format string specified"
+    die "No format string specified"
         if not scalar @{$self->{'parameter'}};
     $self->{'format'} = $self->{'parameter'}->[0];
     return $self;
