@@ -1,7 +1,6 @@
 package DTL::Fast::Parser;
 use strict; use warnings FATAL => 'all'; 
 use parent 'DTL::Fast::Renderer';
-use Carp;
 
 use DTL::Fast::Expression;
 use DTL::Fast::Text;
@@ -10,12 +9,12 @@ sub new
 {
     my( $proto, %kwargs ) = @_;
 
-    croak 'No directory arrays passed into constructor'
+    die 'No directory arrays passed into constructor'
         if not $kwargs{'dirs'}
             or ref $kwargs{'dirs'} ne 'ARRAY'
         ;
     
-    croak 'No raw chunks array passed into constructor'
+    die 'No raw chunks array passed into constructor'
         if not $kwargs{'raw_chunks'}
             or ref $kwargs{'raw_chunks'} ne 'ARRAY'
         ;
@@ -55,7 +54,7 @@ sub parse_next_chunk
         $chunk =~ /^\{\%\s*([^\s]+?)(?:\s+(.*?))?\s*\%\}$/s
     )
     {
-        $chunk = $self->parse_tag_chunk($1, $2);
+        $chunk = $self->parse_tag_chunk(lc $1, $2);
     }
     elsif
     ( 
@@ -82,6 +81,17 @@ sub parse_tag_chunk
     
     my $result = undef;
 
+    # dynamic module loading
+    if( 
+        not exists $DTL::Fast::TAG_HANDLERS{$tag_name} 
+        and exists $DTL::Fast::KNOWN_TAGS{$tag_name} 
+    )
+    {
+        require Module::Load;
+        Module::Load::load($DTL::Fast::KNOWN_TAGS{$tag_name});
+        $DTL::Fast::LOADED_MODULES{$DTL::Fast::KNOWN_TAGS{$tag_name}} = time;            
+    }
+
     if( exists $DTL::Fast::TAG_HANDLERS{$tag_name} )
     {     
         $result = $DTL::Fast::TAG_HANDLERS{$tag_name}->new(
@@ -109,7 +119,7 @@ sub parse_tag_chunk
 sub get_container_block{ 
     my( $self ) = @_;
     return $self->{'_container_block'} 
-        // croak sprintf(
+        // die sprintf(
             "There is no container block in: %s", $self // 'undef'
         ); 
 }
@@ -118,13 +128,13 @@ sub add_blocks
 {
     my( $self, $blocks ) = @_;
     
-    croak "Blocks must be a HASH reference" if ref $blocks ne 'HASH';
+    die "Blocks must be a HASH reference" if ref $blocks ne 'HASH';
     
     foreach my $block_name (keys(%$blocks))
     {
         if( exists $self->{'blocks'}->{$block_name} )
         {
-            croak "Block $block_name is already registered. Duplicate names are not allowed";
+            die "Block $block_name is already registered. Duplicate names are not allowed";
         }
         
         $self->{'blocks'}->{$block_name} = $blocks->{$block_name};
@@ -142,11 +152,11 @@ sub remove_blocks
 {
     my ($self, $block_names ) = @_;
 
-    croak "Blocks must be an ARRAY reference" if ref $block_names ne 'ARRAY';
+    die "Blocks must be an ARRAY reference" if ref $block_names ne 'ARRAY';
      
     foreach my $block_name (@$block_names)
     {
-        croak "Sub-block $block_name does not registered in current block."
+        die "Sub-block $block_name does not registered in current block."
             if not exists $self->{'blocks'}->{$block_name};
             
         delete $self->{'blocks'}->{$block_name};
